@@ -125,14 +125,14 @@ def get_smv_file(path: str):
     elif os.path.isdir(path):
         files = scan_directory_smv(path)
         if len(files) > 1:
-            raise IOError("There are multiple simulations in this path!")
+            raise IOError("There are multiple simulations in the directory:, path")
         elif len(files) == 0:
-            raise IOError("There are no simulations in this path!")
+            raise IOError("No simulations were found in the directory:", path)
         return files[0]
     elif os.path.isfile(path + ".smv"):
         return path + ".smv"
     else:
-        raise IOError("Path is invalid!")
+        raise IOError("The given path does neither point to a directory nor a file:", path)
 
 
 class FDSDataCollection:
